@@ -458,7 +458,28 @@ class NREN
 			}
 		}
 	}
-
+	/**
+	 * getContactEmail()
+	 *
+	 * You can choose if only the contact-address or address + name should be returned
+	 *
+	 *			foo@example.org
+	 *			Foo B. Ar <foo@example.org>
+	 *
+	 * @param Boolean formatted if the address should be nicely formatted for page-inclusion
+	 * @return String the address
+	 * @access public
+	 */
+	public function getContactEmail($formatted=false)
+	{
+		if (!is_null($this->data) && array_key_exists('contact_email', $this->data)) {
+			if ($formatted && array_key_exists('name', $this->data)) {
+				return $this->data['name'] . " <" . $this->data['contact_email'] . ">";
+			}
+			return $this->data['contact_email'];
+		}
+		return false;
+	}
 
 	/**
 	 * setContactPhone()
@@ -863,10 +884,11 @@ class NREN
 	 * getPrivacyNotice() - return the privacy-notice for the NREN
 	 *
 	 * @param Person $person the current person (for translating the tags)
+	 * @return String|null the privacy notice for this NREN
 	 */
 	public function getPrivacyNotice($person)
 	{
-		$query = "SELECT privacy_notice FROM nrens WHERE nren_id = ?";
+		$query = "SELECT privacy_notice FROM nrens WHERE nren_id = ? AND privacy_notice IS NOT NULL";
 		$res = array();
 		try {
 			$res = MDB2Wrapper::execute($query,
@@ -884,6 +906,7 @@ class NREN
 			return "";
 		}
 
+		/* Found something, grab the first hit */
 		if (count($res) > 0) {
 			$pn=$res[0]['privacy_notice'];
 
@@ -891,13 +914,11 @@ class NREN
 			$pn=Input::br2nl($pn);
 			$textile = new Textile();
 
-			/* replalce tags */
+			/* replace tags */
 			return $this->replaceTags($textile->TextileRestricted($pn,0), $person);
 
 		}
-		return "No privacy-notice has yet been set for your NREN (".
-			$this->getName().")<br />";
-
+		return null;
 	}
 
 	/**
@@ -909,20 +930,27 @@ class NREN
 	 */
 	public function getAboutText($person)
 	{
-		$query = "SELECT about FROM nrens WHERE nren_id = ?";
+		$query = "SELECT about FROM nrens WHERE nren_id = ? AND about IS NOT NULL";
 
 		try {
 			$res = MDB2Wrapper::execute($query,
 						    array('text'),
 						    array($this->getID()));
+
 		} catch (DBStatementException $dbse) {
 			Framework::error_output($this->translateMessageTag('abt_err_dbstat') . " " .
 			                        htmlentities($dbse->getMessage()));
-			return "";
+			Logger::log_event(LOG_INFO, "Could not retrive about-text for NREN $nren " .
+							  "due to an error with the statement. " .
+							  "Server said: " . $dbse->getMessage());
+			return null;
 		} catch (DBQueryException $dbqe) {
 			Framework::error_output($this->translateMessageTag('abt_err_dbquery') .  " " .
 			                        htmlentities($nren));
-			return "";
+			Logger::log_event(LOG_INFO, "Could not retrieve about-text for NREN $nren " .
+							  "due to an error in the statement. Server said: " .
+							  $dbqe->getMessage());
+			return null;
 		}
 
 		if (count($res) > 0) {
@@ -934,11 +962,9 @@ class NREN
 
 			return $this->replaceTags($textile->TextileRestricted($at,0), $person);
 		}
-		return "No about-NREN text has been defined for your NREN (" .
-			$this->getName(). ")";
+		return null;
 	}
 
-
 	/**
 	 * getHelpText()
 	 *
@@ -949,7 +975,7 @@ class NREN
 	 */
 	public function getHelpText($person)
 	{
-		$query = "SELECT help FROM nrens WHERE nren_id = ?";
+		$query = "SELECT help FROM nrens WHERE nren_id = ? AND help IS NOT NULL";
 		$res = array();
 		try {
 			$res = MDB2Wrapper::execute($query,
@@ -977,11 +1003,51 @@ class NREN
 			$help_text = $textile->TextileRestricted($help_text,0);
 			return $this->replaceTags($help_text, $person);
 		}
-		return "No Help-text for your NREN (" .
-			$this->getName(). ") can be found in the system.";
+		return null;
 	} /* end getHelpText() */
 
 
+	public function hasAboutText()
+	{
+		$query = "SELECT about FROM nrens WHERE nren_id = ? AND about IS NOT NULL";
+
+		try {
+			$res = MDB2Wrapper::execute($query,
+						    array('text'),
+						    array($this->getID()));
+
+		} catch (Exception $e) {
+			Logger::log_even(LOG_WARN, "Trouble checking for valid about-text (nren-id: ".$this->getID()."), error was " . $e->getMessage());
+		}
+		return count($res)>0;
+	}
+
+	public function hasPrivacyNotice()
+	{
+		$query = "SELECT privacy_notice FROM nrens WHERE nren_id = ? and privacy_notice IS NOT NULL";
+		try {
+			$res = MDB2Wrapper::execute($query,
+						    array('text'),
+						    array($this->getID()));
+		} catch (Exception $e) {
+			Logger::log_even(LOG_WARN, "Trouble checking for valid privacy-notice (nren-id: ".$this->getID()."), error was " . $e->getMessage());
+		}
+		return count($res) > 0;
+	}
+
+	public function hasHelpText()
+	{
+		$query = "SELECT help FROM nrens WHERE nren_id = ? AND help IS NOT NULL";
+		try {
+			$res = MDB2Wrapper::execute($query,
+						    array('text'),
+						    array($this->getID()));
+		} catch (Exception $e) {
+			Logger::log_even(LOG_WARN, "Trouble checking for valid help-text (nren-id: ".$this->getID()."), error was " . $e->getMessage());
+		}
+		return count($res)>0;
+	}
+
 	/**
 	 * Set/update maintenance message for a given NREN.
 	 *
