@@ -134,10 +134,18 @@ class NRENAccount
 							  "Trying to read NREN-account whilst internal state is changed. Aborted.");
 			return false;
 		}
-
-		$query  = "SELECT am.account_map_id, am.login_name, am.password, am.ivector, am.ap_name ";
-		$query .= "FROM account_map am LEFT JOIN nrens n ON n.login_account = am.account_map_id ";
-		$query .= "WHERE n.nren_id=?";
+		if (MDB2Wrapper::testColumn('nrens', 'login_name') &&
+			MDB2Wrapper::testColumn('nrens', 'password') &&
+			MDB2Wrapper::testColumn('nrens', 'ivector') &&
+			MDB2Wrapper::testColumn('nrens', 'ap_name')) {
+			$query = "SELECT login_name, password, ivector, ap_name FROM nrens WHERE nren_id=?";
+			Logger::log_event(LOG_DEBUG, "Using the new schema for account details");
+		} else {
+			$query  = "SELECT am.account_map_id, am.login_name, am.password, am.ivector, am.ap_name ";
+			$query .= "FROM account_map am LEFT JOIN nrens n ON n.login_account = am.account_map_id ";
+			$query .= "WHERE n.nren_id=? AND n.login_account IS NOT NULL";
+			Logger::log_event(LOG_ALERT, "Old database-format is used, it schema should be migrated and data should be moved");
+		}
 
 		/* FIXME:
 		 * add internal state if in error
@@ -158,27 +166,48 @@ class NRENAccount
 							  $this->nren->getID() .": ". $dse->getMessage());
 			return false;
 		}
-
 		if (count($res) == 1) {
-			$this->login_name	= $res[0]['login_name'];
-			$this->ap_name		= $res[0]['ap_name'];
-			$this->account_id	= $res[0]['account_map_id'];
-			$this->password		= trim(base64_decode(mcrypt_decrypt(
-														 MCRYPT_RIJNDAEL_256,
-														 Config::get_config('capi_enc_pw'),
-														 base64_decode($res[0]['password']),
-														 MCRYPT_MODE_CFB,
-														 base64_decode($res[0]['ivector']))));
-			return true;
-		} else if (count($res) > 1) {
-			Logger::log_event(LOG_ALERT,
-							  "Too many account-results returned from DB for NREN " .
-							  $this->nren->getID() .
-							  ". This could indicate that the tables are corrupt (!)");
+			return $this->parseAccountData($res, 0);
+		} else if (count($res) == 0) {
+			return $this->readDeprecatedSchema($this->nren->getID());
 		}
+		Logger::log_event(LOG_ALERT,
+						  "Too many account-results returned from DB for NREN " .
+						  $this->nren->getID() .
+						  ". This could indicate that the tables are corrupt (!)");
 		return false;
 	} /* end read() */
 
+	/**
+	 * try to grap the account_map_id from the old schema.
+	 */
+	private function readDeprecatedSchema($nren_id)
+	{
+		/* test if nren_id is in table */
+		if (MDB2Wrapper::testColumn('account_map', 'nren_id') === true) {
+			try {
+				$res = MDB2Wrapper::execute("SELECT count(*) as count FROM account_map WHERE nren_id = ?",
+											array('integer'),
+											array($nren_id));
+			} catch (Exception $e) {
+				/* doesn't really matter, this is best-effort only */
+				Logger::log_event(LOG_NOTICE, "Could not get nren_id from account_map, error: " . $e->getMessage());
+				return false;
+			}
+			$num =  $res[0]['count'] . "\n";
+			try {
+				$res = MDB2Wrapper::execute("SELECT * FROM account_map WHERE nren_id = ?",
+											array('integer'),
+											array($nren_id));
+			} catch (Exception $e) {
+				/* doesn't really matter, this is best-effort only */
+				Logger::log_event(LOG_NOTICE, "Could not get accounts from account_map, error: " . $e->getMessage());
+				return false;
+			}
+			return $this->parseAccountData($res, 0);
+		}
+	} /* end readDeprecatedSchema() */
+
 	/**
 	 * save() store updated results to the database, encrypting the password
 	 * before storage.
@@ -201,20 +230,27 @@ class NRENAccount
 											   base64_encode($this->password),
 											   MCRYPT_MODE_CFB,
 											   $iv));
-		if (isset($this->account_id)) {
+		if (MDB2Wrapper::testColumn('nrens', 'login_name') &&
+			MDB2Wrapper::testColumn('nrens', 'password') &&
+			MDB2Wrapper::testColumn('nrens', 'ivector') &&
+			MDB2Wrapper::testColumn('nrens', 'ap_name')) {
+			$sql = " UPDATE nrens SET login_name=?, password=?, ivector=?, ap_name=?";
+			$sql.= " WHERE nren_id = ?";
+			Logger::log_event(LOG_DEBUG, "Using the new database-schema for account-details");
+		}
+		else if (isset($this->account_id)) {
 			$sql    = "UPDATE account_map SET login_name=?, password=?, ivector=?, ap_name=?";
-			$sql   .= " WHERE account_map_id = ?";
-			$params = array('text', 'text', 'text', 'text', 'text');
-			$data   = array($this->login_name, $cryptpw, base64_encode($iv), $this->ap_name, $this->account_id);
-
+			$sql   .= " WHERE nren_id = ?";
 		} else {
 			$sql    = "INSERT INTO account_map (login_name, password, ivector, ap_name, nren_id) ";
 			$sql   .= "VALUES(?, ?, ?, ?, ?)";
-			$params = array('text', 'text', 'text', 'text', 'integer');
-			$data   = array($this->login_name, $cryptpw, base64_encode($iv), $this->ap_name, $this->nren->getID());
-			/* Possible BUG: if we try to save() twice in a row for a new
-			 * account, it will explode as it does not have the account_id */
 		}
+		$params = array('text', 'text', 'text', 'text', 'integer');
+		$data   = array($this->login_name,
+						$cryptpw,
+						base64_encode($iv),
+						$this->ap_name,
+						$this->nren->getID());
 
 		try {
 			MDB2Wrapper::update($sql, $params, $data);
@@ -229,13 +265,29 @@ class NRENAccount
 		} catch (DBStatementException $dse) {
 			$errorTag = PW::create();
 			Logger::log_event(LOG_ERR,
-			                  "Could not update the login-account with ID " .
-			                  $this->account_id . " to new value $login_name " . $dse->getMessage());
+			                  "Could not update the login-account for NREN " .
+			                  $this->nren->getID() . " to new value $login_name " . $dse->getMessage());
 			return false;
 		}
 		$this->changed = false;
 		return true;
 	} /* end save() */
 
+	private function parseAccountData($sql_res, $idx)
+	{
+		$this->login_name	= $sql_res[$idx]['login_name'];
+		$this->ap_name		= $sql_res[$idx]['ap_name'];
+		if (array_key_exists('account_map_id', $sql_res[$idx])) {
+			$this->account_id	= $sql_res[$idx]['account_map_id'];
+		}
+
+		$this->password	= trim(base64_decode(mcrypt_decrypt(
+												 MCRYPT_RIJNDAEL_256,
+												 Config::get_config('capi_enc_pw'),
+												 base64_decode($sql_res[$idx]['password']),
+												 MCRYPT_MODE_CFB,
+												 base64_decode($sql_res[$idx]['ivector']))));
+		return true;
+	} /* end parseAccountData() */
 }
 ?>
