@@ -15,6 +15,7 @@ require_once 'CSR.php';
 abstract class CA
 {
   protected $person;
+  protected $owner_string;
   /* the number of days that the certificate issued by the CA will be valid */
   protected $validityDays;
   /* domain components that will be added to the certificate subjects */
@@ -36,6 +37,17 @@ abstract class CA
 		$this->validityDays = $validity;
 		$this->dcs = array();
 
+		$this->owner_string = "User not authN, unknown user!";
+		if ($this->person->isAuth()) {
+			$this->owner_string = "User: ".stripslashes($this->person->getX509ValidCN()) . ".";
+			if (!is_null($this->person->getSubscriber())) {
+				$this->owner_string .= " Subscriber: " . $this->person->getSubscriber()->getIdPName();
+			}
+			if (!is_null($this->person->getNREN())) {
+				$this->owner_string .= " (". $this->person->getNREN()->getName() . ") ";
+			}
+			$this->owner_string .= "via " . $_SERVER['REMOTE_ADDR'];
+		}
     } /* end __construct */
 
   /* this function is quite critical, as it must remove residual information
@@ -133,6 +145,15 @@ abstract class CA
   */
   abstract function getCertListForEPPN($eppn, $org);
 
+  /**
+   * verifyCredentials() test to see if username/password is valid
+   *
+   * @param String $username
+   * @param String $password
+   * @return Boolean true if credentials are valid
+   */
+  abstract function verifyCredentials($username, $password);
+
   /**
    * Send a notification upon the issuance of a new X.509 certificate, as it is
    * required in section 3.2 of the MICS-profile.
@@ -302,9 +323,10 @@ abstract class CA
 	 * instead of /C=SE/O=EvilMastermindes/CN=Dr. Evil
 	 *
 	 * This is needed for in-browser request signing
+	 * @param Boolean ieCNbypass adapt the CN to IE browser-generation (strip ',')
 	 * @return string the DN in comma-separated format
 	 */
-  public function getBrowserFriendlyDN()
+  public function getBrowserFriendlyDN($ieCNbypass = false)
   {
 		$dn = "";
 		foreach ($this->dcs as $dc) {
@@ -314,13 +336,18 @@ abstract class CA
 		$dn .= "C=" . $this->person->getNREN()->getCountry() . ", ";
 
 		$dn .= "O=" . $this->person->getSubscriber()->getOrgName() . ", ";
-		$dn .= "CN=" . stripslashes($this->person->getX509ValidCN());
+		$cn = stripslashes($this->person->getX509ValidCN());
+		if ($ieCNbypass) {
+			$cn = str_replace(",", "", $cn);
+		}
+		$dn .= "CN=" . $cn;
 		if (Config::get_config('cert_product') == PRD_PERSONAL) {
 			$dn .= "/unstructuredName=" . $this->person->getEPPN();
 		}
 		return $dn;
 	}
 
+
 } /* end class CA */
 
 class CAHandler
