@@ -7,6 +7,7 @@ require_once 'send_element.php';
 require_once 'csv_lib.php';
 require_once 'Input.php';
 require_once 'MDB2Wrapper.php';
+require_once 'CS.php';
 
 class CP_RevokeCertificate extends Content_Page
 {
@@ -37,53 +38,6 @@ class CP_RevokeCertificate extends Content_Page
 			}
 		}
 
-		if(isset($_GET['revoke'])) {
-			switch($_GET['revoke']) {
-
-				/* the revoke single is done via a GET
-				 * request. This is to allow for dedicated urls
-				 * for revocation to be used. */
-			case 'revoke_single':
-				$order_number	= Input::sanitizeCertKey($_GET['order_number']);
-				/* sanitized by checking inclusion in the REVOCATION_REASONS
-				 * array
-				 */
-				if (!array_key_exists('reason', $_GET)) {
-					Framework::error_output($this->translateMessageTag('rev_err_singlenoreason'));
-					return;
-				}
-				$reason		= Input::sanitizeText(trim($_GET['reason']));
-				try {
-					if (!isset($order_number) || !isset($reason)) {
-						Framework::error_output("Revoke Certificate: Errors with parameters, not set properly");
-					} elseif (!$this->checkRevocationPermissions($order_number)) {
-						Framework::error_output($this->translateMessageTag('rev_err_singlenoperm'));
-					} elseif (!$this->ca->revokeCert($order_number, $reason)) {
-						Framework::error_output($this->translateMessageTag('rev_err_notyet1') .
-						                        htmlentities($order_number) .
-						                        $this->translateMessageTag('rev_err_notyet2') .
-						                        htmlentities($reason));
-					} else {
-						Framework::message_output($this->translateMessageTag('rev_suc_single1') .
-						                          htmlentities($order_number) .
-						                          $this->translateMessageTag('rev_suc_single2'));
-
-						if (Config::get_config('ca_mode') === CA_COMODO &&
-						    Config::get_config('capi_test') === true) {
-								Framework::message_output($this->translateTag('l10n_msg_revsim1', 'revocation'));
-						}
-					}
-				} catch (ConfusaGenException $cge) {
-					Framework::error_output($this->translateMessageTag('rev_err_singleunspec')
-											. " " . htmlentities($cge->getMessage()));
-				}
-				break;
-			default:
-				Framework::error_output("Unknown operation received in parameter!");
-				break;
-			}
-		}
-
 		if (isset($_POST['revoke_operation'])) {
 			$reason = null;
 			if (array_key_exists('reason', $_POST)) {
@@ -176,7 +130,7 @@ class CP_RevokeCertificate extends Content_Page
 	{
 		if (!$this->person->isAdmin()) {
 			Logger::log_event(LOG_ALERT,
-					  "User " . $this->person->getX509ValidCN() .
+					  "User " . stripslashes($this->person->getX509ValidCN()) .
 					  " allowed to set admin-mode, but is not admin");
 			Framework::error_output("Impossible condition. NON-Admin user in admin-mode!");
 			return;
@@ -223,7 +177,7 @@ class CP_RevokeCertificate extends Content_Page
 				}
 			}
 			if (!is_null($subscriber) && $subscriber instanceof Subscriber) {
-				$this->tpl->assign('active_subscriber', htmlentities($subscriber->getOrgName()));
+				$this->tpl->assign('active_subscriber', $subscriber->getOrgName());
 			}
 			if (! is_null($subscribers)) {
 				$this->tpl->assign('subscribers', $subscribers);
@@ -233,7 +187,7 @@ class CP_RevokeCertificate extends Content_Page
 		} else {
 			/* not specified any subscriber, use user's subscriber */
 			$subscriber = $this->person->getSubscriber()->getOrgName();
-			$this->tpl->assign('active_subscriber', $this->person->getSubscriber()->getOrgName());
+			$this->tpl->assign('active_subscriber', $subscriber);
 		}
 
 
@@ -293,25 +247,28 @@ class CP_RevokeCertificate extends Content_Page
 	 * Not being blessed with the privileges that institution-adminship offers,
 	 * the normal user will only be given the possibility to revoke the full
 	 * set of her own certificates.
+	 *
+	 * @param	void
+	 * @return	void
+	 * @access	private
 	 */
 	 private function showNonAdminRevokeTable()
-	{
-		if (isset($_SESSION['auth_keys'])) {
-			unset($_SESSION['auth_keys']);
-		}
+	 {
+		 CS::deleteSessionKey('auth_keys');
 
 		$eppn = $this->person->getEPPN();
 		$certs = $this->ca->getCertListForEPPN($eppn, $this->person->getSubscriber()->getOrgName());
 		$owners = array();
 		$orders = array();
 		foreach($certs as $row) {
-			$owners[] = $row['cert_owner'];
-			$orders[Input::sanitizeCommonName($row['cert_owner'])][] = $row['auth_key'];
+			$owner = Input::sanitizeCommonName($row['cert_owner']);
+			$owners[] = $owner;
+			$orders[$owner][] = $row['auth_key'];
 		}
 
 		/* total number of occurences for every owner */
 		$stats = array_count_values($owners);
-		$_SESSION['auth_keys'] = $orders;
+		CS::setSessionKey('auth_keys',$orders);
 		$owners = array_unique($owners);
 		$this->tpl->assign('owners', $owners);
 		$this->tpl->assign('stats', $stats);
@@ -341,10 +298,7 @@ class CP_RevokeCertificate extends Content_Page
 	 */
 	private function searchCertsDisplay($common_name, $subscriber)
 	{
-		if (isset($_SESSION['auth_keys'])) {
-			unset($_SESSION['auth_keys']);
-		}
-
+		CS::deleteSessionKey('auth_keys');
 		if (!empty($subscriber)) {
 			$certs = $this->ca->getCertListForPersons($common_name, $subscriber);
 		}
@@ -366,7 +320,7 @@ class CP_RevokeCertificate extends Content_Page
 
 			/* total number of occurences for every owner */
 			$stats = array_count_values($owners);
-			$_SESSION['auth_keys'] = $orders;
+			CS::setSessionKey('auth_keys', $orders);
 			$owners = array_unique($owners);
 			$this->tpl->assign('owners', $owners);
 			$this->tpl->assign('stats', $stats);
@@ -397,16 +351,14 @@ class CP_RevokeCertificate extends Content_Page
 		    Config::get_config('capi_test') === true) {
 			Framework::message_output($this->translateTag('l10n_msg_revsim1', 'revocation'));
 		}
-		$auth_keys = array();
-
-		if (isset($_SESSION['auth_keys'])) {
-			$auth_keys = $_SESSION['auth_keys'];
-			unset($_SESSION['auth_keys']);
-		} else {
+		$auth_keys = CS::getSessionKey('auth_keys');
+		CS::deleteSessionKey('auth_keys');
+		if (is_null($auth_keys)) {
 			Framework::error_output("Lost the certificate identifiers associated with " .
 			                        "common name " .
 			                        htmlentities($common_name) .
 			                        " during the session! Please try again!");
+			return;
 		}
 		if (!array_key_exists($common_name, $auth_keys)) {
 			Framework::error_output("Auth-keys has no such common-name ($common_name). Cannot continue.");
@@ -462,13 +414,12 @@ class CP_RevokeCertificate extends Content_Page
 			Framework::message_output($this->translateTag('l10n_msg_revsim1', 'revocation'));
 		}
 
-		$auth_keys = array();
-		if (isset($_SESSION['auth_keys'])) {
-			$auth_keys = $_SESSION['auth_keys'];
-			unset($_SESSION['auth_keys']);
-		} else {
+		$auth_keys = CS::getSessionKey('auth_keys');
+		CS::deleteSessionKey('auth_keys');
+		if (is_null($auth_keys)) {
 			Framework::error_output("Lost session! Please log-out of Confusa, " .
-									"log-in again and try again!\n");
+						"log-in again and try again!\n");
+			return;
 		}
 
 		$num_certs = count($auth_keys);
@@ -523,9 +474,7 @@ class CP_RevokeCertificate extends Content_Page
 		 * an endless list of auth_keys as hidden parameters
 		 * to the user and then from there back again with a POST to the server
 		 */
-		if (isset($_SESSION['auth_keys'])) {
-			unset($_SESSION['auth_keys']);
-		}
+		CS::deleteSessionKey('auth_keys');
 
 		$csvl = new CSV_Lib($eppn_file);
 		$eppn_list = $csvl->get_csv_entries();
@@ -548,85 +497,13 @@ class CP_RevokeCertificate extends Content_Page
 			}
 
 			$owners = array_unique($owners);
-			$_SESSION['auth_keys'] = $auth_keys;
+			CS::setSessionKey('auth_keys', $auth_keys);
 			$this->tpl->assign('owners', $owners);
 			$this->tpl->assign('revoke_list', true);
 			$this->tpl->assign('nren_reasons', ConfusaConstants::$REVOCATION_REASONS);
 			$this->tpl->assign('selected', 'unspecified');
 		}
 	}
-
-	/**
-	 * Check if the person that called "revoke" on auth_key may revoke the respective
-	 * certificate.
-	 *
-	 * NREN-Admin: Is the certificate issued to one of the subscribers in the
-	 * 			constituency of the NREN?
-	 * Subscriber-Admin: Is the certificate issued to the organization of the admin?
-	 * "Normal" Person: Is the certificate issued to the person herself?
-	 *
-	 * @param $auth_key mixed The auth_key for which to check
-	 * @return boolean true, if revocation of the passed key is permitted
-	 */
-	private function checkRevocationPermissions($auth_key)
-	{
-		try {
-			$info = $this->ca->getCertInformation($auth_key);
-
-			if (is_null($info)) {
-				Framework::error_output("Certificate with the given auth_key/order-number " .
-					"not found! Maybe you misspelled the order-number or auth_key?");
-				return false;
-			}
-
-			/**
-			 * Check if the NREN admin may revoke the certificate. That holds only
-			 * if the organization name in the certificate matches one of the institutions
-			 * in the constituency of the NREN
-			 */
-			if ($this->person->isNRENAdmin()) {
-				$subscribers = $this->getNRENSubscribers($this->person->getNREN());
-
-				foreach ($subscribers as $subscriber) {
-					if ($subscriber->getOrgName() === $info['organization']) {
-						return true;
-					}
-				}
-			/** check if the subscriber admin may revoke the certificate.
-			 * She may do so only if the organization name in the certificate matches
-			 * her own organization
-			 */
-			} else if ($this->person->isSubscriberAdmin() || $this->person->isSubscriberSubAdmin()) {
-				$subscriber = $this->person->getSubscriber()->getOrgName();
-
-				if ($subscriber === $info['organization']) {
-					return true;
-				}
-			/*
-			 * Check if an individual user may revoke a certificate. That holds only
-			 * if the CN of the certificate matches the (constructed) CN of the user and
-			 * the organization the subscriber-organization of the user
-			 *
-			 * */
-			} else {
-				$cn = $this->person->getX509ValidCN();
-				$subscriber = $this->person->getSubscriber()->getOrgName();
-
-				if (($info['cert_owner'] === $cn) && ($info['organization'] === $subscriber)) {
-					return true;
-				}
-			}
-
-		} catch (ConfusaGenException $cge) {
-			Framework::error_output("Retrieving certificate information failed: " .
-							htmlentities($cge->getMessage()));
-			Logger::log_event(LOG_INFO, "[nadm][sadm][norm] Revoking certificate " .
-				"with key $auth_key failed, because permissions could not be " .
-				"determined!");
-		}
-
-		return false;
-	} /* end checkRevocationPermissions */
 }
 
 $fw = new Framework(new CP_RevokeCertificate());
