@@ -36,9 +36,9 @@ class CP_Root_Certificate extends Content_Page
 			}
 		} else {
 			$this->cert_path = Config::get_config('install_path') .
-								Config::get_config('ca_cert_base_path') .
-								Config::get_config('ca_cert_path') .
-								Config::get_config('ca_cert_name');
+				Config::get_config('ca_cert_base_path') .
+				Config::get_config('ca_cert_path') .
+				Config::get_config('ca_cert_name');
 			$this->crl_path = ConfusaConstants::$OPENSSL_CRL_FILE;
 
 			$this->cert_url = "?link=cacert";
@@ -62,36 +62,41 @@ class CP_Root_Certificate extends Content_Page
 			include_once 'file_download.php';
 			switch(htmlentities($_GET['send_file'])) {
 			case 'cacert':
-				$this->makeCertAvailable();
-				$cert = new Certificate(file_get_contents($this->cert_path));
-				$idx = strrpos($this->cert_url, "/");
-				$cert_name = substr($this->cert_url, $idx+1);
-				download_file($cert->getPEMContent(), $cert_name);
+				try {
+					$this->makeCertAvailable();
+					$cert = new Certificate(file_get_contents($this->cert_path));
+					$idx = strrpos($this->cert_url, "/");
+					$cert_name = substr($this->cert_url, $idx+1);
+					download_file($cert->getPEMContent(), $cert_name);
+				} catch (ConfusaGenException $cge) {
+					Framework::error_output($this->translateTag('l10n_cacert_fetch_error', 'rootcert'));
+				}
 				break;
+
 			case 'cachain':
-				$this->makeChainAvailable();
-				$idx = strrpos($this->cert_url, "/");
-				$cert_name = substr($this->cert_url, $idx+1);
-				$dot_idx = strrpos($cert_name, ".");
-				$cert_name = substr($cert_name, 0, $dot_idx);
-				$cert_name = $cert_name . '_bundle.pem';
-				download_file(file_get_contents($this->cert_path), $cert_name);
-				break;
-			case 'cachain':
-				$this->makeChainAvailable();
-				$idx = strrpos($this->cert_url, "/");
-				$cert_name = substr($this->cert_url, $idx+1);
-				$dot_idx = strrpos($cert_name, ".");
-				$cert_name = substr($cert_name, 0, $dot_idx);
-				$cert_name = $cert_name . '_bundle.pem';
-				download_file(file_get_contents($this->cert_path), $cert_name);
+				try {
+					$this->makeChainAvailable();
+					$idx = strrpos($this->cert_url, "/");
+					$cert_name = substr($this->cert_url, $idx+1);
+					$dot_idx = strrpos($cert_name, ".");
+					$cert_name = substr($cert_name, 0, $dot_idx);
+					$cert_name = $cert_name . '_bundle.pem';
+					download_file(file_get_contents($this->cert_path), $cert_name);
+				} catch (ConfusaGenException $cge) {
+					Framework::error_output($this->translateTag('l10n_cachain_fetch_error', 'rootcert'));
+				}
 				break;
+
 			case 'crl':
-				$this->makeCRLAvailable();
-				$crl = new CRL(file_get_contents($this->crl_path));
-				$idx = strrpos($this->crl_url, "/");
-				$crl_name = substr($this->crl_url, $idx+1);
-				download_file($crl->getPEMContent(), $crl_name);
+				try {
+					$this->makeCRLAvailable();
+					$crl = new CRL(file_get_contents($this->crl_path));
+					$idx = strrpos($this->crl_url, "/");
+					$crl_name = substr($this->crl_url, $idx+1);
+					download_file($crl->getPEMContent(), $crl_name);
+				} catch (ConfusaGenException $cge) {
+					Framework::error_output($this->translateTag('l10n_crl_fetch_error', 'rootcert'));
+				}
 				break;
 			default:
 				return;
@@ -100,7 +105,6 @@ class CP_Root_Certificate extends Content_Page
 		} else if (isset($_GET['link']) && file_exists($this->cert_path)) {
 			switch(htmlentities($_GET['link'])) {
 			case 'cacert':
-				require_once('Certificate.php');
 				$cert = new Certificate(file_get_contents($this->cert_path));
 				header("Content-type: application/x-x509-ca-cert");
 				// IE fix (for HTTPS only)
@@ -130,21 +134,29 @@ class CP_Root_Certificate extends Content_Page
 	public function process()
 	{
 		if (isset($_GET['show_root_cert'])) {
-			$this->makeCertAvailable();
-			$cdata = file_get_contents($this->cert_path);
-			$cert = new Certificate($cdata);
-			$this->tpl->assign('ca_dump', $cert->getPEMContent(false));
+			try {
+				$this->makeCertAvailable();
+				$cdata = file_get_contents($this->cert_path);
+				$cert = new Certificate($cdata);
+				$this->tpl->assign('ca_dump', $cert->getPEMContent(false));
+			} catch (ConfusaGenException $cge) {
+				Framework::error_output($this->translateTag('l10n_cacert_fetch_error', 'rootcert'));
+			}
 		}
 
 		if (isset($_GET['show_crl'])) {
-			$this->makeCRLAvailable();
-			$crl = new CRL(file_get_contents($this->crl_path));
-			$this->tpl->assign('crl_dump', $crl->getPEMContent(false));
+			try {
+				$this->makeCRLAvailable();
+				$crl = new CRL(file_get_contents($this->crl_path));
+				$this->tpl->assign('crl_dump', $crl->getPEMContent(false));
+			} catch (ConfusaGenException $cge) {
+				Framework::error_output($this->translateTag('l10n_crl_fetch_error', 'rootcert'));
+			}
 		}
 
 		$this->tpl->assign('ca_download_link',	$this->cert_url);
 		$this->tpl->assign('crl_download_link',	$this->crl_url);
-		$this->tpl->assign('content',		$this->tpl->fetch('root_cert.tpl'));
+		$this->tpl->assign('content',			$this->tpl->fetch('root_cert.tpl'));
 	}
 
 	/**
@@ -158,13 +170,8 @@ class CP_Root_Certificate extends Content_Page
 	private function makeCRLAvailable()
 	{
 		if(Config::get_config('ca_mode') == CA_COMODO) {
-			$ch = curl_init($this->crl_url);
-			curl_setopt($ch, CURLOPT_RETURNTRANSFER,true);
-			$crl_content = curl_exec($ch);
-
+			$crl_content = CurlWrapper::curlContact($this->crl_url);
 			$crl = new CRL($crl_content);
-
-			curl_close($ch);
 			file_put_contents($this->crl_path, $crl->getPEMContent(true));
 		}
 	}
@@ -177,14 +184,8 @@ class CP_Root_Certificate extends Content_Page
 	private function makeCertAvailable()
 	{
 		if(Config::get_config('ca_mode') == CA_COMODO) {
-			$ch = curl_init($this->cert_url);
-			curl_setopt($ch, CURLOPT_RETURNTRANSFER,true);
-			$ca_file_content = curl_exec($ch);
-
-			/* convert from DER to PEM */
+			$ca_file_content = CurlWrapper::curlContact($this->cert_url);
 			$cert = new Certificate($ca_file_content);
-
-			curl_close($ch);
 			file_put_contents($this->cert_path, $cert->getPEMContent(true));
 		}
 	}
@@ -198,27 +199,16 @@ class CP_Root_Certificate extends Content_Page
 	private function makeChainAvailable()
 	{
 		if (Config::get_config('ca_mode') == CA_COMODO) {
-			$ch = curl_init(ConfusaConstants::$CAPI_ROOT_CA);
-			curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
-			$root_ca_content = curl_exec($ch);
-			curl_close($ch);
-
-			$ch = curl_init(ConfusaConstants::$CAPI_INTERMEDIATE_CA);
-			curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
-			$interm_ca_content = curl_exec($ch);
-			curl_close($ch);
-
-			$ch = curl_init($this->cert_url);
-			curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
-			$actual_ca_cert = curl_exec($ch);
-			curl_close($ch);
+			$root_ca_content   = CurlWrapper::curlContact(ConfusaConstants::$CAPI_ROOT_CA);
+			$interm_ca_content = CurlWrapper::curlContact(ConfusaConstants::$CAPI_INTERMEDIATE_CA);
+			$actual_ca_cert    = CurlWrapper::curlContact($this->cert_url);
 
 			/* convert from DER to PEM */
 			$cert = new Certificate($actual_ca_cert);
 
 			$ca_chain = $root_ca_content .
-			            $interm_ca_content .
-			            $cert->getPEMContent(true);
+				$interm_ca_content .
+				$cert->getPEMContent(true);
 
 			file_put_contents($this->cert_path, $ca_chain);
 		}
